<?php

namespace TVn7\EventBundle\Entity;

use Doctrine\ORM\Mapping as ORM;

use TVn7\EventBundle\Entity\Clip;

use Gedmo\Mapping\Annotation as Gedmo;
use Symfony\Component\Validator\Constraints as Assert;
use Symfony\Bridge\Doctrine\Validator\Constraints\UniqueEntity;
use Symfony\Component\Validator\Context\ExecutionContextInterface;

/**
 * ClipType
 *
 * @ORM\Table(name="tdb_event_clip_type")
 * @ORM\Entity(repositoryClass="TVn7\EventBundle\Repository\ClipTypeRepository")
 * @UniqueEntity(fields="name", message="Il existe déjà un type de clip avec ce nom.")
 * @Gedmo\Loggable(logEntryClass="TVn7\LogBundle\Entity\AppsLog")
 */
class ClipType
{
    /**
     * @var int
     *
     * @ORM\Column(name="id", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $id;

    /**
     * @var string
     *
     * @ORM\Column(name="name", type="string", length=255)
     * @Assert\NotBlank()
     * @Assert\Length(min = 2, max = 50)
     * @Assert\Type(type="string")
     * @Gedmo\Versioned
     */
    private $name;

    /**
     * @var Clip
     * @ORM\OneToMany(targetEntity="TVn7\EventBundle\Entity\Clip", mappedBy="type")
     */
    private $clips;
    
    /**
     * @var string
     * @Gedmo\Slug(fields={"name"}, updatable=false)
     * @ORM\Column(name="slug", type="string", length=255, unique=true)
     */
    private $slug;
    
    /**
     * 
     * @return string
     */
    public function __toString() {
        return $this->name;
    }
    
    /**
     * Constructor
     */
    public function __construct()
    {
        $this->clips = new \Doctrine\Common\Collections\ArrayCollection();
    }

    /**
     * Get id
     *
     * @return integer
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set name
     *
     * @param string $name
     *
     * @return ClipType
     */
    public function setName($name)
    {
        $this->name = $name;

        return $this;
    }

    /**
     * Get name
     *
     * @return string
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     * Add clip
     *
     * @param \TVn7\EventBundle\Entity\Clip $clip
     *
     * @return ClipType
     */
    public function addClip(\TVn7\EventBundle\Entity\Clip $clip)
    {
        $this->clips[] = $clip;

        return $this;
    }

    /**
     * Remove clip
     *
     * @param \TVn7\EventBundle\Entity\Clip $clip
     */
    public function removeClip(\TVn7\EventBundle\Entity\Clip $clip)
    {
        $this->clips->removeElement($clip);
    }

    /**
     * Get clips
     *
     * @return \Doctrine\Common\Collections\Collection
     */
    public function getClips()
    {
        return $this->clips;
    }
    
    public function isDeletableSafely() {
        return (count($this->clips) == 0);
    }
    
    /**
     * Set slug
     *
     * @param string $slug
     *
     * @return Music
     */
    public function setSlug($slug)
    {
        $this->slug = $slug;

        return $this;
    }

    /**
     * Get slug
     *
     * @return string
     */
    public function getSlug()
    {
        return $this->slug;
    }
    
    /**
     * 
     * @return \Doctrine\Common\Collections\Collection
     */
    public function getClipsNoDel() {
        return $this->getClips()->filter(function($p) {
            return $p->getDeleted() == false;
        });
    }
    
    public function getColor() {
        $sum = 0;
        $name = str_split(md5($this->name));
        foreach($name as $c) {
            $sum+=ord($c);
        }
        switch($sum%5) {
            case 0:
                $bg="primary";
                break;
            case 1:
                $bg="success";
                break;
            case 2:
                $bg="info";
                break;
            case 3:
                $bg="warning";
                break;
            case 4:
                $bg="danger";
                break;
        }
        return $bg;
    }

}
